<?php

require_once "database.php";

// Eine einfache Klasse zur Verwaltung von Benutzern
// Diese Klasse bietet statische Methoden zur Überprüfung vorhandener Benutzer
// und zum Erstellen neuer Benutzer in der Datenbank.
class Users {
    // Überprüft, ob ein Benutzer mit der angegebenen E-Mail existiert und gibt dessen ID zurück
    // $email: Die E-Mail des zu überprüfenden Benutzers
    // Gibt die Benutzer-ID zurück, wenn gefunden, sonst null
    public static function getUserIdByEmail(string $email): ?int {
        $db = new Database();
        $sql = "SELECT id FROM user WHERE email = ?";
        $result = $db->query($sql, [$email]);
        $user = $db->fetchOne($result);

        return $user ? (int)$user['id'] : null;
    }

    // Erstellt einen neuen Benutzer in der Datenbank
    // $name: Der Name des Benutzers
    // $email: Die E-Mail des Benutzers
    // $telephone: Die Telefonnummer des Benutzers
    // Gibt die ID des neu erstellten Benutzers zurück
    public static function createUser(string $name, string $email, string $telephone): int {
        $db = new Database();
        $sql = "INSERT INTO user (name, email, telephone) VALUES (?, ?, ?)";
        $db->query($sql, [$name, $email, $telephone]);

        // Hole die ID des neu erstellten Benutzers
        return self::getUserIdByEmail($email);
    }

    // Holt Benutzerinformationen anhand der Benutzer-ID
    // $userId: Die ID des Benutzers
    // Gibt ein Array mit Benutzerinformationen zurück oder null, wenn nicht gefunden
    public static function getUserById(int $userId): ?array {
        $db = new Database();
        $sql = "SELECT id, name, email, telephone FROM user WHERE id = ?";
        $result = $db->query($sql, [$userId]);

        return $db->fetchOne($result);
    }
}
